@@ -16,6 +16,9 @@ from seaborn import heatmap
 
 
 
+
+
+
 import sys
 import warnings
 if not sys.warnoptions:
@@ -39,21 +42,6 @@ from . import save_load_algorithms
 
 
 
-# from functools import wraps
-
-# def get_docs(func):
-#     @wraps(func)           
-#     def wrapper(*args, **kwargs):
-#         # result = func(*args, **kwargs)
-#         # wrapper.__name__ = func.__name__
-#         wrapper.__doc__ = func.__doc__
-#         return result
-#     return wrapper
-
-def get_docs(func):
-    def wrapper(*args, **kwargs):
-        return func(func, *args, **kwargs)
-    return wrapper
 
 
 
@@ -64,59 +52,57 @@ class Snaplib__222:
     ENCODER = encoder.Encoder()
 
 
+
+
     @staticmethod
-    @get_docs
     def nan_info(df : pd.DataFrame) -> pd.DataFrame:
-        # '''
-        # Get pandas.DataFrame with information about missing data in columns
-        # Use case:
-        # missing_info_df = Snaplib().nan_info(df)
-        # '''
+        '''
+        Get pandas.DataFrame with information about missing data in columns
+        Use case:
+        missing_info_df = Snaplib().nan_info(df)
+        '''
         return nans.nan_info(df)
 
 
 
 
     @staticmethod
-    @get_docs
     def nan_plot(df : pd.DataFrame) -> plt.figure:
-        # '''
-        # Visualise missing data in pandas.DataFrame
-        # Use case:
-        # Snaplib().nan_plot(df)
-        # '''
+        '''
+        Visualise missing data in pandas.DataFrame
+        Use case:
+        Snaplib().nan_plot(df)
+        '''
         return nans.nan_plot(df)
 
 
 
 
     @staticmethod
-    @get_docs
     def cleane( df : pd.DataFrame, 
                 target : str = None, 
                 verbose : bool = True
                 ) -> pd.DataFrame: 
-        # '''
-        # drop_duplicates
-        # drop rows with nan in target
-        # drop column with 1 unique value
-        # Use case:
-        # df = Snaplib().cleane(df, target_name, verbose=True)
-        # '''
+        '''
+        drop_duplicates
+        drop rows with nan in target
+        drop column with 1 unique value
+        Use case:
+        df = Snaplib().cleane(df, target_name, verbose=True)
+        '''
         return nans.cleane(df, target, verbose)
 
 
 
-    @get_docs
     def encode_dataframe(self, 
                          df : pd.DataFrame, 
                          inplace : bool = False, 
                          ) -> pd.DataFrame: 
-        # '''
-        # encode a dataframe
-        # Use case:
-        # df = Snaplib().encode_dataframe(df)
-        # '''
+        '''
+        encode a dataframe
+        Use case:
+        df = Snaplib().encode_dataframe(df)
+        '''
         if inplace is False:
             df_copied = df.copy()
 
@@ -126,16 +112,15 @@ class Snaplib__222:
 
 
         
-    @get_docs
     def decode_dataframe(self, 
                          df : pd.DataFrame, 
                          inplace : bool = False, 
                          ) -> pd.DataFrame: 
-        # '''
-        # encode a dataframe
-        # Use case:
-        # df = Snaplib().decode_dataframe(df)
-        # '''
+        '''
+        encode a dataframe
+        Use case:
+        df = Snaplib().decode_dataframe(df)
+        '''
         if inplace is False:
             df_copied = df.copy()
             return self.ENCODER.decode_dataframe(df_copied)
@@ -967,7 +952,7 @@ class Snaplib:
                                     task='clsf' or 'regr', 
                                     verbose= 0, 1,
                                     early_stopping_rounds=0 or positve int
-                                    ):
+                                    )
         
         algorithms_list = list of algorithms [LGBMClassifier(), XGBClassifier(), CatBoostClassifier()].
         X_train and y_train are data for training list of algorithms.
@@ -975,6 +960,7 @@ class Snaplib:
         y_test optionaly. If exist visualize it as last column on a plot (verbose=True). 
         task='clsf' or 'regr', classification or regression
         verbose = 0 mute, 1 verbose.
+        early_stopping_rounds=0 or positve int.
 
         '''
         if type(algorithms_list) != list:
@@ -1346,12 +1332,13 @@ class Snaplib:
                                                 X_val=None, 
                                                 y_val=None,
                                                 verbose=0,
-                                                ):
+                                                early_stopping_rounds=0
+                                                )
         
         algorithms_list = list of algorithms [LGBMClassifier(), XGBClassifier(), CatBoostClassifier()].
         X_train and y_train are data for training list of algorithms.
-
         verbose = 0 mute, 1 verbose.
+        early_stopping_rounds=0 or positve int
         '''
 
         if type(algorithms_list) != list:
